@@ -55,10 +55,9 @@ from smbprotocol.open import (
 log = logging.getLogger(__name__)
 
 
-# Not defined on Python 2.6 so try and get the attribute with a sane default
-SEEK_SET = getattr(io, 'SEEK_SET', 0)
-SEEK_CUR = getattr(io, 'SEEK_CUR', 1)
-SEEK_END = getattr(io, 'SEEK_END', 2)
+SEEK_SET = io.SEEK_SET
+SEEK_CUR = io.SEEK_CUR
+SEEK_END = io.SEEK_END
 
 
 def _parse_share_access(raw, mode):
@@ -131,8 +130,11 @@ def _chunk_size(connection, length, operation):
     # Determine how many credits we need to fully optimize subsequent calls for the remaining amount of data. Basically
     # how many credits we need to send either the remaining data or the max operation size.
     remaining_length = min(max(0, length - chunk_size), max_size)
-    consumed_credits = math.ceil(chunk_size / MAX_PAYLOAD_SIZE)
-    credit_request = consumed_credits + math.ceil(remaining_length / MAX_PAYLOAD_SIZE)
+    consumed_credits = (max(0, chunk_size - 1) // MAX_PAYLOAD_SIZE) + 1
+    remaining_credits = (max(0, remaining_length - 1) // MAX_PAYLOAD_SIZE) + 1
+    desired_credits = max(0, remaining_credits - available_credits - consumed_credits)
+
+    credit_request = consumed_credits + desired_credits
 
     return chunk_size, int(credit_request)
 
@@ -561,6 +563,7 @@ class SMBRawIO(io.RawIOBase):
 
         chunk_size, credit_request = _chunk_size(self.fd.connection, len(b), 'read')
 
+        print(f"Read {self._offset} - {chunk_size}")
         read_msg, recv_func = self.fd.read(self._offset, chunk_size, send=False)
         request = self.fd.connection.send(
             read_msg,
@@ -591,12 +594,7 @@ class SMBRawIO(io.RawIOBase):
         the length of b as it depends on the underlying connection.
         """
         chunk_size, credit_request = _chunk_size(self.fd.connection, len(b), 'write')
-
-        # Python 2 compat, can be removed and just use the else statement.
-        if isinstance(b, memoryview):
-            data = b[:chunk_size].tobytes()
-        else:
-            data = bytes(b[:chunk_size])
+        data = bytes(b[:chunk_size])
 
         write_msg, recv_func = self.fd.write(data, offset=self._offset, send=False)
         request = self.fd.connection.send(
